Documo v0.1.0 Documo.Numbers View Source

Module implementing the Documo fax numbers API.

Link to this section Summary

Functions

Provision a fax number. Provisioned fax numbers incur a monthly charge. Provision type is hard-coded to "order" presently in this library.

NB: Use "npa" param to search for specific area code.

Link to this section Functions

Link to this function

list(params \\ %{}, headers \\ %{})

Specs

Ref: https://docs.documo.com/#retrieve-fax-numbers

Link to this function

provision(arg, headers \\ %{})

Specs

Provision a fax number. Provisioned fax numbers incur a monthly charge. Provision type is hard-coded to "order" presently in this library.

The number being provisioned must be passed in E164 format, and must have appeared in a number search within the last 24 hours.

Ref: https://docs.documo.com/#provision-fax-numbers

Link to this function

release(number_id, headers \\ %{})

Specs

Ref: https://docs.documo.com/#release-number

Link to this function

search(params \\ %{}, headers \\ %{})

Specs

NB: Use "npa" param to search for specific area code.

Ref: https://docs.documo.com/#search-for-available-numbers