Documo v0.1.0 Documo.Numbers View Source
Module implementing the Documo fax numbers API.
Link to this section Summary
Functions
Provision a fax number. Provisioned fax numbers
incur a monthly charge. Provision type is
hard-coded to "order" presently in this library.
NB: Use "npa" param to search for specific area code.
Link to this section Functions
Specs
list(map(), map()) :: Documo.Client.client_response()
Specs
provision(String.t(), map()) :: Documo.Client.client_response()
Provision a fax number. Provisioned fax numbers
incur a monthly charge. Provision type is
hard-coded to "order" presently in this library.
The number being provisioned must be passed in E164 format, and must have appeared in a number search within the last 24 hours.
Specs
release(String.t(), map()) :: Documo.Client.client_response()
Specs
search(map(), map()) :: Documo.Client.client_response()
NB: Use "npa" param to search for specific area code.